@@ -1198,7 +1198,7 @@ sub _run {
     defined $sub and return &$sub( $command, @args );
 
     my ( $out, $err, $res ) = capture { system $command };
-    print STDERR $err if $err;
+    $self->log($err) if $err;
     $self->{_run_exit} = $res >> 8;
     return wantarray ? split /(\r\n|\r|\n)/, $out : $out;
 }
